Index: program/include/rcmail.php
===================================================================
--- program/include/rcmail.php	(revision 40a1860174c612c4d60754b328fa572a7879f1e3)
+++ program/include/rcmail.php	(revision c9f4e9bc659a06f6d12c21ddfba0432ccf654e99)
@@ -356,14 +356,15 @@
    * Initialize and get cache object
    *
    * @param string $name Cache identifier
    * @param string $type Cache type ('db', 'apc' or 'memcache')
    * @param int    $ttl  Expiration time for cache items in seconds
    *
    * @return rcube_cache Cache object
    */
-  public function get_cache($name, $type='db', $ttl=0)
+  public function get_cache($name, $type='db', $ttl=0, $packed=true)
   {
     if (!isset($this->caches[$name])) {
-      $this->caches[$name] = new rcube_cache($type, $_SESSION['user_id'], $name, $ttl);
+      $this->caches[$name] = new rcube_cache($type, $_SESSION['user_id'], $name, $ttl, $packed);
     }
 
@@ -356,14 +356,15 @@
    * Initialize and get cache object
    *
-   * @param string $name Cache identifier
-   * @param string $type Cache type ('db', 'apc' or 'memcache')
-   * @param int    $ttl  Expiration time for cache items in seconds
+   * @param string $name   Cache identifier
+   * @param string $type   Cache type ('db', 'apc' or 'memcache')
+   * @param int    $ttl    Expiration time for cache items in seconds
+   * @param bool   $packed Enables/disables data serialization
    *
    * @return rcube_cache Cache object
